@@ -5,7 +5,7 @@ from typing import Optional
 import betterlogging
 from aiopg import create_pool
 from aiogram import Dispatcher
-from aiogram.types import Update
+from aiogram.types import Update, User
 from aiogram.contrib.middlewares.i18n import I18nMiddleware
 from psycopg2.sql import Identifier
 
@@ -22,13 +22,21 @@ __all__ = [
 
 async def _get_user_locale() -> Optional[str]:
     dp = Dispatcher.get_current()
+    lang = None
+
     for middleware in dp.middleware.applications:
+
         if isinstance(middleware, I18nMiddleware):
             try:
-                lang = await middleware.get_user_locale('', tuple())
+                lang = await middleware.get_user_locale('', (None,))
+                break
             except Exception:
-                lang = None
-            return lang
+                continue
+
+        if not lang:
+            lang = User.get_current().locale
+
+        return lang
 
 
 async def register(dsn: str, table_name: str):
