@@ -1,7 +1,7 @@
 import asyncio
 import inspect
 
-from api import handle_event
+from aiogram_metrics.api import handle_event
 
 
 def track(arg):
